import { Navigate, Outlet } from "react-router-dom";
import { useStateContext } from "../contexts/ContextProvider";
import axiosClient from "../axios-client.js";
import { useState, useEffect } from "react";


export default function AdminLayout() {

    const {user, token, setUser, setToken, notification} = useStateContext();

    if (!token) {
        return <Navigate to="/login" />
    }

    
    const onLogout = ev => {
        ev.preventDefault()

        axiosClient.post('/logout')
        .then(() => {
            setUser({})
            setToken(null)
        })
    }

    useEffect(() => {
        axiosClient.get('/user')
        .then(({data}) => {
            setUser(data)
        })
    }, [])

    const [isClassAdded, setIsClassAdded] = useState(false);

    useEffect(() => {
        if (isClassAdded) {
          document.body.classList.add('sidenav-toggled');
        } else {
          document.body.classList.remove('sidenav-toggled');
        }
      }, [isClassAdded]);

      const toggleClass = () => {
        setIsClassAdded(!isClassAdded);
      };

    return (
        <>
            <nav className="topnav navbar navbar-expand shadow justify-content-between justify-content-sm-start navbar-light bg-white" id="sidenavAccordion">
                {/* <!-- Navbar Brand-->
                <!-- * * Tip * * You can use text or an image for your navbar brand.-->
                <!-- * * * * * * When using an image, we recommend the SVG format.-->
                <!-- * * * * * * Dimensions: Maximum height: 32px, maximum width: 240px--> */}
                <a className="navbar-brand" href="index.html">PGDX_RAFFLE</a>
                {/* <!-- Sidenav Toggle Button--> */}
                <button className="btn btn-icon btn-transparent-dark order-1 order-lg-0 mr-lg-2" onClick={toggleClass} id="sidebarToggle"><i className="fa fa-bars"></i></button>
                {/* <!-- Navbar Items--> */}
            </nav>
            <div id="layoutSidenav">
                <div id="layoutSidenav_nav">
                    <nav className="sidenav shadow-right sidenav-light">
                        <div className="sidenav-menu">
                            <div className="nav accordion" id="accordionSidenav">
                                {/* <!-- Sidenav Heading (UI Toolkit)--> */}
                                <div className="sidenav-menu-heading text-center">RAFFLE</div>
                                {/* <!-- Sidenav Accordion (Layout)--> */}
                                <a className="nav-link collapsed active" href="/dashboard">
                                    <div className="nav-link-icon"><i className="fa fa-cubes"></i></div>
                                    Items
                                </a>
                                <a className="nav-link collpased" onClick={onLogout} style={{cursor: 'pointer'}}
                                >
                                    <div className="nav-link-icon"><i className="fa fa-arrow-left"></i></div>Sign Out
                                </a>

                                <form id="logout-form" action="#" method="POST" className="d-none">
                                    @csrf
                                </form>
                            </div>
                        </div>
                    </nav>
                </div>
                <div id="layoutSidenav_content">
                    <main>
                       <Outlet />
                    </main>
                    {notification &&
                    <div className="notification">
                        {notification}
                    </div>
                    }
                    <footer className="footer mt-auto footer-light">
                        <div className="container-fluid">
                            <div className="row">
                                <div className="col-md-6 small">Copyright &copy; Your Website 2023</div>
                                {/* <!-- <div className="col-md-6 text-md-right small">
                                    <a href="#!">Privacy Policy</a>
                                    &middot;
                                    <a href="#!">Terms &amp; Conditions</a>
                                </div> --> */}
                            </div>
                        </div>
                    </footer>
                </div>
            </div>
        </>
    )
}