import React, { useState } from 'react';
import { useTable } from 'react-table';
import { TextField, Table, TableBody, TableCell, TableContainer, TableHead, TableRow, Paper, Button, Dialog, DialogTitle, DialogActions, DialogContent } from '@mui/material';
import { styled } from '@mui/system';

const StyledTableContainer = styled(TableContainer)`
  background-color: #00000073;
  margin-top: 10px;
`;

const StyledTable = styled(Table)`
  color: #fff;
`;

const StyledTableCell = styled(TableCell)`
  font-weight: bold;
  color: #fff;
`;

const StyledDataTableCell = styled(TableCell)`
  color: #fff;
  font-size: 20px;
  font-weight: bold;
`;

const StyledImageCell = styled(TableCell)`
  padding: 8px;
`;

const StyledTableCellHeader = styled(TableCell)`
  font-weight: bold;
  color: #fff;
  border-bottom: none;
`;



// const Button = styled(TableCell)`
//   background-color: transparent;
// `;

const CustomTable = ({ columns, data, onEdit, onDelete }) => {
  const {
    getTableProps,
    getTableBodyProps,
    headerGroups,
    rows,
    prepareRow,
  } = useTable({ columns, data });

  const [searchTerm, setSearchTerm] = useState('');
  const [selectedImage, setSelectedImage] = useState('');
  const [openDialog, setOpenDialog] = useState(false);

  const filteredData = data.filter((row) =>
    columns.some((column) => {
      const cellValue = row[column.accessor];
      if (typeof cellValue === 'string') {
        return cellValue.toLowerCase().includes(searchTerm.toLowerCase());
      }
      return false;
    })
  );

  const handleOpenDialog = (imageUrl) => {
    setSelectedImage(imageUrl);
    setOpenDialog(true);
  };

  const handleCloseDialog = () => {
    setOpenDialog(false);
  };


  const handleSearchChange = (e) => {
    setSearchTerm(e.target.value);
  };
  

  return (
    <>
    <TextField
        label="Search"
        value={searchTerm}
        onChange={handleSearchChange}
        // variant="outlined"
        size="small"
        className="form-control"
    />
    <StyledTableContainer component={Paper}>
        <StyledTable>
          <TableHead>
            <TableRow>
              {columns.map((column) => (
                <StyledTableCell key={column.Header}>{column.Header}</StyledTableCell>
              ))}
               <StyledTableCell>
              <StyledTableCellHeader>Image</StyledTableCellHeader>
              </StyledTableCell>
              <StyledTableCell>
                <StyledTableCellHeader>Action</StyledTableCellHeader>
              </StyledTableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {filteredData.map((row) => (
              <TableRow key={row.id}>
                {columns.map((column) => (
                  <StyledDataTableCell key={column.accessor}>{row[column.accessor]}</StyledDataTableCell>
                ))}
                <StyledImageCell>
                    <img  src={'http://127.0.0.1:8000'+row.image} alt="Item" style={{ width: '50px', height: '50px' }} />
                    <Button variant="outlined" onClick={() => handleOpenDialog(row.image)}>View Image</Button>
                </StyledImageCell>
                <StyledDataTableCell>
                  <Button variant="contained" onClick={() => onEdit(row.id)}>Edit</Button>
                  <Button variant="contained" onClick={() => onDelete(row.id)}>Delete</Button>
                </StyledDataTableCell>
              </TableRow>
            ))}
          </TableBody>
        </StyledTable>
      </StyledTableContainer>
      <Dialog open={openDialog} onClose={handleCloseDialog}>
        <DialogTitle>Image Preview</DialogTitle>
        <DialogContent>
          <img src={'http://127.0.0.1:8000'+selectedImage} alt="Item" style={{ width: '100%' }} />
        </DialogContent>
        <DialogActions>
          <Button onClick={handleCloseDialog}>Close</Button>
        </DialogActions>
      </Dialog>
    </>
  );
};

export default CustomTable;
