import {useEffect, useState} from "react";
import axiosClient from "../axios-client.js";
import {Link, useNavigate} from "react-router-dom";
import {useStateContext} from "../contexts/ContextProvider.jsx";
import CustomTable from '../components/Table';



export default function Dashboard() {

    const [items, setItems] = useState([]);
    const [loading, setLoading] = useState(false);
    const {setNotification} = useStateContext()
    const navigate = useNavigate();
  
    useEffect(() => {
      getItems();
    }, [])
  
    const handleDelete = item => {
      if (!window.confirm("Are you sure you want to delete this item?")) {
        return
      }
      axiosClient.delete(`/items/${item}`)
        .then(() => {
          setNotification('Item was successfully deleted')
          getItems()
        })
    }

    const handleEdit = (rowId) => {
      navigate('item/'+rowId)
    };
  
    const getItems = () => {
      setLoading(true)
      axiosClient.get('/items')
        .then(({ data }) => {
          setLoading(false)
          setItems(data.data)
        })
        .catch(() => {
          setLoading(false)
        })
    }

    const columns = [
        {
          Header: 'Item',
          accessor: 'item',
        },
        {
          Header: 'Quantity',
          accessor: 'quantity',
        },
        {
          Header: 'Probability',
          accessor: 'probability',
        },
      ];

    return (
        <>
            <div className="row justify-content-center">
                <div className="container mt-10">
                    <div className="card">
                        <div className="card-header">Prize List
                          <Link style={{ float: 'right' }} className="btn btn-primary" to="/dashboard/item/new">Add</Link>
                        </div>
                        <div className="card-body">
                        {loading ? (
                            <div style={{color: '#000'}}>Loading...</div>
                            ) : (
                            items.length > 0 ? (
                                <CustomTable columns={columns} data={items} onEdit={handleEdit} onDelete={handleDelete} />
                            ) : (
                                <div style={{color: '#000'}}>No data available.</div>
                            )
                        )}
                        </div>
                    </div>
                </div>
            </div>
        </>
    )
}