import React, { useEffect, useState } from 'react';
import axiosClient from '../axios-client';
import vidSrc from "../assets/3starwish-single.mp4";
import gifSrc from "../assets/explosion.gif";
import Echo from 'laravel-echo';
import Pusher from 'pusher-js';

export default function Draw() {
  const [showVideo, setShowVideo] = useState(false);
  const [showReset, setShowReset] = useState(false);
  const [showNumber, setShowNumber] = useState(false);
  const [selectedPrize, setSelectedPrize] = useState(null);
  const [selectedItemId, setSelectedItemId] = useState(null);
  const [selectedItemImage, setSelectedItemImage] = useState(null);
  const [loading, setLoading] = useState(false);
  const [showGif, setShowGif] = useState(false);

  useEffect(() => {
    // Fetch initial data from the server
    setLoading(true);
    axiosClient.get('/items')
      .then(({ data }) => {
        // Set initial data in the component state
        // ...
        setLoading(false);
      })
      .catch(() => {
        setLoading(false);
      });

    // Initialize WebSockets connection
    const pusher = new Pusher('e4cdef5ea6b5f8a97c1c', {
      cluster: 'ap1',
      encrypted: true,
      // Adjust other options as needed
    });

    const channel = pusher.subscribe('draw-channel');

    channel.bind('DrawPrize', (data) => {
        // console.log(data);
      // Handle the prize drawn event
      const { item, itemId, itemImage } = data;
      setSelectedPrize(item);
      setSelectedItemId(itemId);
      setSelectedItemImage(itemImage);
    //   setShowVideo(false);
    //   setShowNumber(true);
    //   setShowGif(true);
    //   setShowReset(true);
    //   const timeout = setTimeout(() => {
    //     setShowGif(false);
    //   }, 1500);
    });

    return () => {
      // Clean up the WebSockets connection
      pusher.unsubscribe('draw-channel');
    };
  }, []);

  const handleButtonClick = () => {
    setShowGif(false);
    setShowNumber(false);
    setShowVideo(true);
    setLoading(false);

    // Send the draw request to the server
    axiosClient.post('/draw')
      .then(response => {
        // Handle the successful response
        console.log(response.data.message);
      })
      .catch(error => {
        // Handle the error
        console.error(error);
      });
  };

  const handleVideoEnd = () => {
     // Only trigger the end logic if the video has been fully played
    //  console.log(selectedItemId);
        setShowVideo(false);
        setShowNumber(true);
        setShowGif(true);
        setShowReset(true);
        const timeout = setTimeout(() => {
          setShowGif(false);
        }, 1500);
  };

  const handleDrawAgain = () => {
    window.location.reload();
  };

  return (
    <div className="__drawBox">
      {showGif && (
        <div className="gif-container">
          <img className="gif fade-in" src={gifSrc} alt="Loading GIF" />
        </div>
      )}
      <div className={`number ${showNumber ? 'fade-in' : ''}`}>
        {showNumber && (
          <>
            <div>
              <img src={`http://127.0.0.1:8000${selectedItemImage}`} alt="" />
            </div>
            <div style={{ fontSize: '50px', fontWeight: 'bold', lineHeight: '50px', color: '#fff', letterSpacing: '10px', textTransform: 'uppercase', textAlign: 'center' }}>
              {selectedPrize}
            </div>
          </>
        )}
      </div>
      {loading && (
        <div>Loading ...</div>
      )}
      {!showVideo && !showReset && (
        <div style={{ marginTop: '50px' }}>
          <button className="btn customBtn" onClick={handleButtonClick}>DRAW</button>
        </div>
      )}
      {!showVideo && showReset && (
        <div style={{ marginTop: '50px' }}>
          <button className="btn customBtn" onClick={handleDrawAgain}>RELOAD</button>
        </div>
      )}
      {showVideo && (
        <div style={{ height: '100vh', overflow: 'hidden' }}>
          <video src={vidSrc} onEnded={handleVideoEnd} autoPlay />
        </div>
      )}
    </div>
  );
}
