import {useNavigate, useParams} from "react-router-dom";
import {useEffect, useState} from "react";
import axiosClient from "../axios-client.js";
import {useStateContext} from "../contexts/ContextProvider.jsx";

export default function UserForm() {
  const navigate = useNavigate();
  let {id} = useParams();
  const [item, setItem] = useState({
    id: null,
    item: '',
    image: null,
    imageName: '',
    quantity: '',
    probability: ''
  })
  const [errors, setErrors] = useState(null)
  const [loading, setLoading] = useState(false)
  const {setNotification} = useStateContext()
  const [selectedFile, setSelectedFile] = useState(null);

  useEffect(() => {
    if (id !== "new") {
      setLoading(true);
      axiosClient.get(`/items/${id}`)
        .then(({ data }) => {
          setLoading(false);
          setItem(data);
        })
        .catch(() => {
          setLoading(false);
        });
    }
  }, [id]);

  const handleImageChange = (event) => {
    const file = event.target.files[0];
    setItem({ ...item, image: file, imageName: file.name });
  };

  const onSubmit = ev => {
    ev.preventDefault()
    setLoading(true);

    const headers = {
      'Content-Type': 'multipart/form-data',
    };

    const formData = new FormData();
    formData.append('item', item.item);
    formData.append('image', item.image);
    formData.append('quantity', item.quantity);
    formData.append('probability', item.probability);

    if (id && id !== 'new') {
      // Append additional data for edit mode
      formData.append('_method', 'PUT');
    }

        const request = id && id !== "new"
        ? axiosClient.post(`/items/${id}`, formData, {headers})
        : axiosClient.post('/items', formData, {headers});

      request
        .then(() => {
          setLoading(false);
          const message = id && id !== "new" ? 'Item was successfully updated' : 'Item was successfully created';
          setNotification(message);
          navigate('/dashboard');
        })
        .catch((err) => {
          setLoading(false);
          const response = err.response;
          console.log(response);
          if (response && response.status === 422) {
            setErrors(response.data.errors);
          }
    });
  }

  return (
    <>
      <div className="container mt-10">
          <div className="row justify-content-center">
            <div className="col-md-6">
              <div className="card">
                <div className="card-header">
                  {item.id && <div>Update Item: {item.item}</div>}
                  {!item.id && <div>New Item</div>}
                </div>
                <div className="card-body">
                    <div className="animated fadeInDown">
                      {loading && (
                        <div className="text-center">
                          Loading...
                        </div>
                      )}
                      {errors &&
                        <div className="alert alert-danger">
                          {Object.keys(errors).map(key => (
                            <p key={key}>{errors[key][0]}</p>
                          ))}
                        </div>
                      }
                      {!loading && (
                        <form onSubmit={onSubmit}>
                          <div className="mb-3">
                            <label htmlFor="item" className="form-label">Item Name</label>
                            <input className="form-control" name="item" value={item.item} onChange={ev => setItem({...item, item: ev.target.value})} placeholder="Name"/>
                          </div>
                          <div className="mb-3">
                            <label htmlFor="image" className="form-label">Item Image</label>
                            <input className="form-control" name="image" type="file" onChange={handleImageChange} />
                          </div>
                          <div className="mb-3">
                            <label htmlFor="quantity" className="form-label">Quantity</label>
                            <input className="form-control" name="quantity" value={item.quantity} onChange={ev => setItem({...item, quantity: ev.target.value})} placeholder="Email"/>
                          </div>
                          <div className="mb-3">
                            <label htmlFor="probability" className="form-label">Item Name</label>
                            <input className="form-control" name="probability" value={item.probability} onChange={ev => setItem({...item, probability: ev.target.value})} placeholder="Email"/>
                          </div>
                          <button className="btn btn-primary">Save</button>
                        </form>
                      )}
                    </div>
                </div>
              </div>
            </div>
          </div>
      </div>
    </>
  )
}