import {Link} from "react-router-dom";
import axiosClient from "../axios-client.js";
import {createRef} from "react";
import {useStateContext} from "../contexts/ContextProvider.jsx";
import { useState } from "react";

export default function Login() {

    
    const emailRef = createRef()
    const passwordRef = createRef()
    const { setUser, setToken } = useStateContext()
    const [errors, setErrors] = useState(null)

    const onSubmit = ev => {
        ev.preventDefault()

        const payload = {
            email: emailRef.current.value,
            password: passwordRef.current.value,
        }
        axiosClient.post('/login', payload)
        .then(({data}) => {
            setUser(data.user)
            setToken(data.token);
        })
        .catch((err) => {
            const response = err.response;
            if (response && response.status === 422) {
                setErrors(response.data.errors)
            }
        })
    }

    return (
        <>
            <div className="login-body">
                <div className="login-box">
                    <div className="login-header">login</div>
                    <div className="login-form-body">
                        <form className="custom-login-form" onSubmit={onSubmit} >

                        {errors &&
                            <div className="alert alert-danger">
                            {Object.keys(errors).map(key => (
                                <p key={key}>{errors[key][0]}</p>
                            ))}
                            </div>
                        }

                            <div className="form-group has-feedback">
                                <input ref={emailRef} placeholder="email" type="email" className="form-control" />
                            </div>
                            <div className="form-group has-feedback">
                                <input ref={passwordRef} type="password" className="form-control" placeholder="Password"/>
                            </div>
                            <div className="form-group has-feedback">
                                <button className="btn btn-warning form-control">LOGIN</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </>
    )
}